@@ -44,7 +44,7 @@ struct _CalBackendWCAPClass {
 
 void				cal_backend_wcap_write_cache (CalBackendWCAP *wcap);
 void				cal_backend_wcap_add_component (CalBackendWCAP *wcap, icalcomponent *icalcomp,
-													gboolean process, char **old_object);
+													gboolean process, char **old_object, char **new_object);
 void				cal_backend_wcap_remove_component (CalBackendWCAP *wcap, const char *uid, CalObjModType mod, char **old_object);
 void				cal_backend_wcap_verify_exists_uid (CalBackendWCAP *wcap, const char *uid);
 gint				cal_backend_wcap_instance_list_compare (gconstpointer a, gconstpointer b);
