@@ -18,7 +18,7 @@
 #include <libedataserver/e-source.h>
 #include <libedataserver/e-source-list.h>
 #include "lib/sunone-connection.h"
-#include "lib/sunone-account.h"
+#include "sunone-account.h"
                          
 G_BEGIN_DECLS
 
